/*

Copyright (C) 2008, 2009 Jaroslav Hajek

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>.

*/

#define MINCLUDE "ov-re-mat.h"

#define LMATRIX perm_matrix
#define LDMATRIX matrix
#define RMATRIX matrix

#define LSHORT pm
#define RSHORT m

#define LEFT
#define DEFINENULLASSIGNCONV

#include "op-pm-template.cc"
